Package: distrMod
Version: 2.9.7
Date: 2025-01-12
Title: Object Oriented Implementation of Probability Models
Description: Implements S4 classes for probability models based on packages 'distr' and
            'distrEx'.
Authors@R: c(person("Matthias", "Kohl", role=c("aut", "cph")), person("Peter", "Ruckdeschel",
            role=c("cre", "cph"), email="peter.ruckdeschel@uni-oldenburg.de"), person("R Core
            Team", role = c("ctb", "cph"), comment="for source file 'format.perc'"))
Depends: R(>= 3.4), distr(>= 2.8.0), distrEx(>= 2.8.0), RandVar(>=
        1.2.0), MASS, stats4, methods
Imports: startupmsg, sfsmisc, graphics, stats, grDevices
Suggests: ismev, evd,
Enhances: RobExtremes, RobAStBase
ByteCompile: yes
License: LGPL-3
URL: http://distr.r-forge.r-project.org/
LastChangedDate: {$LastChangedDate: 2024-10-23 22:45:36 +0200 (Mi, 23
        Okt 2024) $}
LastChangedRevision: {$LastChangedRevision: 1480 $}
VCS/SVNRevision: 1501
NeedsCompilation: no
Packaged: 2025-01-11 23:28:36 UTC; ruckdesc
Author: Matthias Kohl [aut, cph],
  Peter Ruckdeschel [cre, cph],
  R Core Team [ctb, cph] (for source file 'format.perc')
Maintainer: Peter Ruckdeschel <peter.ruckdeschel@uni-oldenburg.de>
Repository: CRAN
Date/Publication: 2025-01-14 14:30:02 UTC
Built: R 4.3.3; ; 2025-01-14 16:40:36 UTC; unix
