import("methods")
importFrom("grDevices", "col2rgb", "dev.new", "rgb", "grey")
importFrom("graphics", "abline", "legend", "lines", "mtext", "par",
           "points", "text", "title")
importFrom("stats", "aggregate", "approxfun", "complete.cases",
           "dbinom", "dnbinom", "dnorm", "dpois", "na.omit", "optim",
           "optimize", "ppoints", "qchisq", "qnbinom", "qnorm", "quantile")
import("MASS")
import("distr")
import("distrEx")
import("RandVar")
importFrom("startupmsg", "buildStartupMessage")
importFrom("startupmsg", "infoShow")
importFrom("stats4","profile")
importFrom("sfsmisc", "D2ss", "D1ss")

exportClasses("MatrixorFunction", "OptionalNumericOrMatrixOrCall",
              "OptionalDistrListOrCall", "OptionalNumericOrMatrix", 
			  "ShowDetails",
              "FunctionSymmetry", "NonSymmetric", "EvenSymmetric", "OddSymmetric",
              "FunSymmList",
              "ParamFamParameter",
              "ProbFamily", "ParamFamily", "L2ParamFamily")
exportClasses("RiskType", 
              "asRisk", "asCov", "trAsCov", "asHampel", "asBias", "asGRisk",
              "asMSE", "asUnOvShoot",
              "fiRisk", "fiCov", "trFiCov", "fiHampel", "fiMSE", "fiBias",
              "fiUnOvShoot")
exportClasses("BiasType", "onesidedBias", "asymmetricBias", "symmetricBias")
exportClasses("asSemivar", "asRiskwithBias")
exportClasses("L2GroupParamFamily", "L2LocationFamily", 
              "L2ScaleFamily", "L2LocationScaleFamily")
exportClasses("L2LocationScaleUnion")
exportClasses("L2ScaleShapeUnion", "L2ScaleUnion")
exportClasses("ParamWithScaleFamParameter", "ParamWithShapeFamParameter", 
              "ParamWithScaleAndShapeFamParameter")
exportClasses("BinomFamily","PoisFamily", "NormLocationFamily",
       "NormScaleFamily", "ExpScaleFamily",
       "LnormScaleFamily", "GammaFamily", "BetaFamily", "NormLocationScaleFamily",
       "CauchyLocationScaleFamily", "LogisticLocationScaleFamily", "CauchyLocationFamily")
exportClasses("NormType", "QFNorm", "InfoNorm", "SelfNorm")
exportClasses("Estimate", "MCEstimate", "MLEstimate", "MDEstimate", "CvMMDEstimate")
exportClasses("Confint")
exportMethods("distrSymm")
exportMethods("distribution", "props", "props<-", "addProp<-", "main", "main<-",
              "nuisance", "nuisance<-", "trafo", "trafo<-", "trafo.fct", 
              "fixed", "fixed<-", "modifyParam",
              "dimension", "show", "print", "plot", "param", "E", "name",
              "L2deriv", "L2derivSymm", "L2derivDistr", "L2derivDistrSymm",
              "FisherInfo", "checkL2deriv", "fam.call")
exportMethods("completecases")
exportMethods("bound", "width")
exportMethods("nu", "name", "sign", "nu<-", "name<-", "sign<-", "biastype", "biastype<-")
exportMethods("existsPIC")
exportMethods("modifyModel")
exportMethods("norm",  "QuadForm<-", "QuadForm", "fct", 
              "fct<-", "normtype", "normtype<-")
exportMethods("r", "d", "p", "q", "q.l",
              "estimate", "estimate.call", "samplesize.estimate", "call.estimate",
              "name.estimate", "trafo.estimate", "nuisance.estimate", 
              "fixed.estimate", "Infos", "Infos<-", "addInfo<-",
              "criterion", "criterion<-", "criterion.fct", "method",
              "samplesize", "asvar", "asvar<-", "optimwarn", "optimReturn",
			  "withPosRestr", "withPosRestr<-")
exportMethods("untransformed.estimate", "untransformed.asvar")
exportMethods("confint")
exportMethods("validParameter")
exportMethods("startPar", "makeOKPar")
exportMethods("scaleshapename", "scalename", "LogDeriv")
exportMethods("coerce", "profile", "locscalename", "scaleshapename<-")
exportMethods("mleCalc", "mceCalc")
exportMethods("qqplot", "returnlevelplot", ".checkEstClassForParamFamily")
export("distrModMASK")
export("trafoEst")
export("distrModOptions", "distrModoptions", "getdistrModOption",
       "Estimator", "MCEstimator", "MLEstimator", "MDEstimator",
       "CvMMDEstimator", "KolmogorovMDEstimator", "TotalVarMDEstimator", 
       "HellingerMDEstimator")
export("NonSymmetric", "EvenSymmetric", "OddSymmetric", "FunSymmList") 
export("ParamFamParameter", "ParamFamily", "L2ParamFamily",
       "BinomFamily", "PoisFamily", "NbinomFamily", "NormLocationFamily",
       "NormScaleFamily", "ExpScaleFamily", "LogisticLocationScaleFamily",
       "LnormScaleFamily", "GammaFamily", "BetaFamily", "NormLocationScaleFamily",
       "CauchyLocationScaleFamily", "NbinomwithSizeFamily", "NbinomMeanSizeFamily",
	   "LogisticLocationScaleFamily", "CauchyLocationFamily",
	   "NormFamily", "CauchyFamily", "LogisticFamily")
export("asCov", "trAsCov", "asHampel", "asBias", "asMSE", "asUnOvShoot", 
       "fiCov", "trFiCov", "fiHampel", "fiMSE", "fiBias", "fiUnOvShoot")
export("positiveBias", "negativeBias", "symmetricBias", 
       "asymmetricBias", "asSemivar", "LOGISTINT2")
export("isKerAinKerB")
export("L2LocationFamily", "L2ScaleFamily", "L2LocationScaleFamily")
export("EuclideanNorm", "QuadFormNorm")
export("NormType", "QFNorm", "InfoNorm", "SelfNorm")
export("NormScaleUnknownLocationFamily", "NormLocationUnknownScaleFamily")
export("L2LocationUnknownScaleFamily", "L2ScaleUnknownLocationFamily")
export("meRes", "get.criterion.fct")
export("addAlphTrsp2col")
export(".deleteDim",".isUnitMatrix",
       ".CvMMDCovariance", ".oldCvMMDCovariance", ".CvMMDCovarianceWithMux")
S3method(print, relMatrix)